@@ -1,6 +1,6 @@
 #######################################################################
 # arules - Mining Association Rules and Frequent Itemsets
-# Copyright (C) 2011, 2012 Michael Hahsler, Christian Buchta, 
+# Copyright (C) 2011-2015 Michael Hahsler, Christian Buchta, 
 #			Bettina Gruen and Kurt Hornik
 #
 # This program is free software; you can redistribute it and/or modify
@@ -21,17 +21,28 @@
 
 ## aggregate items to item groups
 setMethod("aggregate", signature(x = "itemMatrix"),
-	function(x, itemLabels) {
-	    itemLabels <- as.factor(itemLabels)
+	function(x, by) {
+	    
+	    ## we can specify the name from itemInfo in by
+	    if(length(by) == 1 && !is.null(itemInfo(x)[[by]])) {
+	      by <- itemInfo(x)[[by]]
+	    }
+	  
+	    by <- as.factor(by)
 
-	    if(length(itemLabels) != nitems(x)) stop("Supplied number of itemLabels does not match number of items in x!")
+	    if(length(by) != nitems(x)) stop("Name not available in itemInfo or supplied number of by does not match number of items in x!")
 
-	    aggrMat <- as(sapply(levels(itemLabels),
-			    FUN = function(l) as.numeric(itemLabels == l)), 
-		    "dgCMatrix")
+	    aggrMat <- as(sapply(levels(by),
+			    FUN = function(l) as.numeric(by == l)), "dgCMatrix")
 
-	    x@data <- as(crossprod(aggrMat, as(as(x, "ngCMatrix"), "dgCMatrix")), "ngCMatrix")
-	    x@itemInfo <- data.frame(labels = levels(itemLabels))
+	    x@data <- as(crossprod(aggrMat, as(as(x, "ngCMatrix"), "dgCMatrix")), 
+	      "ngCMatrix")
+	    
+	    #x@itemInfo <- data.frame(labels = levels(by))
+	    ii <- x@itemInfo
+	    ii <- aggregate(ii, by = list(labels = by), FUN = unique)
+	    ii <- ii[,!sapply(ii, is.list), drop = FALSE]
+	    x@itemInfo <- ii
 
 	    validObject(x)
 	    x
@@ -40,9 +51,9 @@ setMethod("aggregate", signature(x = "itemMatrix"),
 	})
 
 setMethod("aggregate", signature(x = "itemsets"),
-	function(x, itemLabels) {
+	function(x, by) {
 
-	    new("itemsets", items=aggregate(items(x), itemLabels))
+	    new("itemsets", items=aggregate(items(x), by))
 	    
       ## first support value is used
 	    x <- unique(x)
@@ -50,10 +61,10 @@ setMethod("aggregate", signature(x = "itemsets"),
 	})
 
 setMethod("aggregate", signature(x = "rules"),
-	function(x, itemLabels) {
+	function(x, by) {
 
-	    rhs <- aggregate(rhs(x), itemLabels)
-	    lhs <- aggregate(lhs(x), itemLabels)
+	    rhs <- aggregate(rhs(x), by)
+	    lhs <- aggregate(lhs(x), by)
 
       ## check if lhs items have to be removed
       lhs <- itemSetdiff(lhs, rhs)
