@@ -1,6 +1,6 @@
 #######################################################################
 # arules - Mining Association Rules and Frequent Itemsets
-# Copyright (C) 2011, 2012 Michael Hahsler, Christian Buchta, 
+# Copyright (C) 2011-2015 Michael Hahsler, Christian Buchta, 
 #			Bettina Gruen and Kurt Hornik
 #
 # This program is free software; you can redistribute it and/or modify
@@ -39,16 +39,19 @@ apriori <-  function(data, parameter = NULL, appearance = NULL, control = NULL)
     parameter <- as(parameter, "APparameter")
 
     if(control@verbose) {
+      cat("Apriori\n")
       ## print parameter
       cat("\nParameter specification:\n")
       print(parameter)
       cat("\nAlgorithmic control:\n")
       print(control)
-      cat("\n")
     }
     
     ## sanity check for support (abs. support >1)
     abs_supp <- as.integer(parameter@support * length(data))
+    if(control@verbose) {
+      cat("\nAbsolute minimum support count:", abs_supp,"\n\n")
+    }
     if(abs_supp < 2) warning(sprintf("You chose a very low absolute support count of %d. You might run out of memory! Increase minimum support.\n", abs_supp),
         immediate.=TRUE)
 
