@@ -1,6 +1,6 @@
 #######################################################################
 # arules - Mining Association Rules and Frequent Itemsets
-# Copyright (C) 2011, 2012 Michael Hahsler, Christian Buchta, 
+# Copyright (C) 2011-2015 Michael Hahsler, Christian Buchta, 
 #			Bettina Gruen and Kurt Hornik
 #
 # This program is free software; you can redistribute it and/or modify
@@ -35,16 +35,19 @@ eclat <-  function(data, parameter = NULL, control = NULL)
     control <- as(control, "ECcontrol")
     
     if(control@verbose) {
+      cat("Eclat\n")
       ## print parameter
       cat("\nparameter specification:\n")
       print(parameter)
       cat("\nalgorithmic control:\n")
       print(control)
-      cat("\n")
     }
 
     ## sanity check for support (abs. support >1)
     abs_supp <- as.integer(parameter@support * length(data))
+    if(control@verbose) {
+      cat("\nAbsolute minimum support count:", abs_supp,"\n\n")
+    }
     if(abs_supp < 2) warning(sprintf("You chose a very low absolute support count of %d. You might run out of memory! Increase minimum support.\n", abs_supp), 
         immediate.=TRUE)
 
